pub enum Commands {
Init,
Tui,
Sessions,
Restore {
event_id: i64,
},
Hooks {
command: HooksCommands,
},
Daemon {
command: DaemonCommands,
},
HookRelay,
}Variants
Init
Initialize chronicle in the current project
Tui
Launch the TUI dashboard
Sessions
List recorded sessions
Restore
Restore files to their state at a specific event
Hooks
Manage hooks
Fields

command: HooksCommandsDaemon
Manage the chronicle daemon
Fields

command: DaemonCommandsHookRelay
Relay hook data from stdin to the daemon (used by hook scripts)