pub struct ActorQuery<'a> { /* private fields */ }Expand description
Query handle for an Actor node in the chronicle graph.
Provides methods to inspect the actor’s data, events, interactions, and computed status at a point in time.
Implementations
Sourceimpl<'a> ActorQuery<'a>
impl<'a> ActorQuery<'a>
Sourcepub fn events_during(&self, range: RangeInclusive<i32>) -> Vec<&'a Event>
pub fn events_during(&self, range: RangeInclusive<i32>) -> Vec<&'a Event>
Events filtered by time range.
Sourcepub fn interactions(&self) -> InteractionResult<'a>
pub fn interactions(&self) -> InteractionResult<'a>
All other actors this actor has co-participated in events with.