PlaceQuery

Struct PlaceQuery 

pub struct PlaceQuery<'a> { /* private fields */ }
Query handle for a Place node in the chronicle graph.

Provides methods to inspect events at this location, actors present at a point in time, and computed status.

Implementations

Source

impl<'a> PlaceQuery<'a>

pub fn data(&self) -> &'a Place

Returns a reference to the underlying Place data.

pub fn events(&self) -> Vec<&'a Event>

All events at this place.

pub fn events_during(&self, range: RangeInclusive<i32>) -> Vec<&'a Event>

Events at this place filtered by time range.

pub fn actors_present_at(&self, year: i32) -> Vec<&'a Actor>

All actors who participated in events at this place during a given year.

pub fn status_at(&self, year: i32) -> Status

Status at a given point in time.